<?php

namespace Drupal\dosd\Commands;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drush\Commands\DrushCommands;

/**
 * A drush command file.
 *
 * @package Drupal\dosd\Commands
 */
class DosdDrushParser extends DrushCommands {
  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * DosdDrushParser constructor.
   */
  public function __construct(ConfigFactoryInterface $configFactory) {
    parent::__construct();
    $this->configFactory = $configFactory;
  }

  /**
   * Drush command that displays the given text.
   *
   * @param string $start_date
   *   Start date.
   * @param string $end_date
   *   End date.
   * @param int $company
   *   Company ID.
   * @param int $user
   *   User ID.
   *
   * @command dosd:parse
   * @aliases dosdp
   * @usage drush dosd:parse 2022/10/14 2022/10/22 2114867 --verbose
   *   Parse credits in the given time interval the company with id
   */
  public function parse(
    string $start_date,
    string $end_date,
    string $company = NULL,
    string $user = NULL,
  ): void {
    // @ToDo: Why config is used here?
    $this->configFactory->getEditable('dosd.settings')
      ->set('company', (int) trim($company))
      ->set('user', trim($user))
      ->set('start_date', trim($start_date))
      ->set('end_date', trim($end_date))
      ->save();
    $this->output()->writeln('Company - ' . $company);
    $this->output()->writeln('User - ' . $user);
    $this->output()->writeln('Start date - ' . $start_date);
    $this->output()->writeln('End date - ' . $end_date);

    $type = \Drupal::service('plugin.manager.dosd.parser');
    $type->collectCredits();
  }

}
